@@ -5,8 +5,9 @@ from django.views.decorators.clickjacking import xframe_options_exempt
 
 try:
     import channels_graphql_ws
-    GraphQLView.graphiql_template = "graphene/graphiql-ws.html"
+    GraphQLView.graphiql_template = "balder/graphiql-ws.html"
 except:
+    GraphQLView.graphiql_template  = "balder/graphiql.html"
     pass
 
 
